@@ -69,6 +69,9 @@ class DownloaderBase:
         observer=_ignore,
         statistics_gatherer=_ignore,
         progress_bar=progress_bar,
+        resume_transfers=False,
+        override_target_file=True,
+        download_file_extension=None,
         **kwargs,
     ):
         self.url = url
@@ -78,12 +81,17 @@ class DownloaderBase:
         self.observer = observer
         self.statistics_gatherer = statistics_gatherer
         self.progress_bar = progress_bar
+        self.resume_transfers = resume_transfers
+        self.override_target_file = override_target_file
+        self.download_file_extension = download_file_extension
 
     def local_path(self):
         return None
 
-    def extension(self):
-        url_no_args = self.url.split("?")[0]
+    def extension(self, url=None):
+        if url is None:
+            url = self.url
+        url_no_args = url.split("?")[0]
         base = os.path.basename(url_no_args)
         extensions = []
         while True:
@@ -95,17 +103,18 @@ class DownloaderBase:
             extensions.append(".unknown")
         return "".join(reversed(extensions))
 
-    def download(self, target, resume_transfers=False, override_target_file=True):
-        if os.path.exists(target) and not override_target_file:
+    def download(self, target):
+        if os.path.exists(target) and not self.override_target_file:
             return
 
-        download = target + ".download"
+        if self.download_file_extension is not None:
+            download = target + ".download"
+        else:
+            download = target
+
         LOG.info("Downloading %s", self.url)
 
         size, mode, skip, trust_size = self.prepare(download)
-        if not resume_transfers:
-            skip = 0
-            mode = "wb"
 
         with self.progress_bar(
             total=size,
@@ -123,7 +132,8 @@ class DownloaderBase:
                 os.path.getsize(download) == size
             ), f"File size mismatch {os.path.getsize(download)} bytes instead of {size}"
 
-        os.rename(download, target)
+        if download != target:
+            os.rename(download, target)
 
         self.finalise()
         return total
