@@ -12,6 +12,7 @@ import datetime
 import json
 import logging
 import os
+import random
 import time
 
 import pytz
@@ -44,6 +45,7 @@ class HTTPDownloaderBase(DownloaderBase):
         range_method=None,
         maximum_retries=500,
         retry_after=120,
+        mirrors=None,
         **kwargs,
     ):
         super().__init__(url, **kwargs)
@@ -55,6 +57,7 @@ class HTTPDownloaderBase(DownloaderBase):
         self.range_method = range_method
         self.retry_after = retry_after
         self.maximum_retries = maximum_retries
+        self.mirrors = mirrors
 
     def headers(self):
         if self._headers is None or self.url != self._url:
@@ -107,7 +110,6 @@ class HTTPDownloaderBase(DownloaderBase):
         headers = self.headers()
         if "content-disposition" in headers:
             value, params = cgi.parse_header(headers["content-disposition"])
-            assert value == "attachment", value
             if "filename" in params:
                 return params["filename"]
         return super().title()
@@ -174,6 +176,10 @@ class HTTPDownloaderBase(DownloaderBase):
         return False
 
     def check_for_restarts(self, target):
+
+        if not self.resume_transfers:
+            return 0
+
         if not os.path.exists(target):
             return 0
 
@@ -204,7 +210,7 @@ class HTTPDownloaderBase(DownloaderBase):
         headers = {}
         headers.update(self.http_headers)
         if bytes_ranges is not None:
-            headers["x-ms-range"] = bytes_ranges
+            headers["range"] = bytes_ranges
 
         LOG.debug("Issue request for %s", self.url)
         LOG.debug("Headers: %s", json.dumps(headers, indent=4, sort_keys=True))
@@ -224,10 +230,13 @@ class HTTPDownloaderBase(DownloaderBase):
         return r
 
     def robust(self, call):
-        return robust(call, self.maximum_retries, self.retry_after)
+        return robust(call, self.maximum_retries, self.retry_after, self.mirrors)
 
 
 class FullHTTPDownloader(HTTPDownloaderBase):
+    def __repr__(self):
+        return f"FullHTTPDownloader({self.url})"
+
     def prepare(self, target):
         assert self.parts is None
 
@@ -273,6 +282,9 @@ class FullHTTPDownloader(HTTPDownloaderBase):
 class PartHTTPDownloader(HTTPDownloaderBase):
     _server_cabilities = None
 
+    def __repr__(self):
+        return f"PartHTTPDownloader({self.url, self.parts})"
+
     @property
     def server_cabilities(self):
         if self._server_cabilities is None:
@@ -400,23 +412,29 @@ class PartHTTPDownloader(HTTPDownloaderBase):
         return (size, "wb", 0, True)
 
 
-def robust(call, maximum_tries=500, retry_after=120):
+RETRIABLE = (
+    requests.codes.internal_server_error,
+    requests.codes.bad_gateway,
+    requests.codes.service_unavailable,
+    requests.codes.gateway_timeout,
+    requests.codes.too_many_requests,
+    requests.codes.request_timeout,
+)
+
+
+def robust(call, maximum_tries=500, retry_after=120, mirrors=None):
     def retriable(code):
+        return code in RETRIABLE
 
-        return code in (
-            requests.codes.internal_server_error,
-            requests.codes.bad_gateway,
-            requests.codes.service_unavailable,
-            requests.codes.gateway_timeout,
-            requests.codes.too_many_requests,
-            requests.codes.request_timeout,
-        )
-
-    def wrapped(*args, **kwargs):
+    def wrapped(url, *args, **kwargs):
         tries = 0
+        main_url = url
+
         while tries < maximum_tries:
             try:
-                r = call(*args, **kwargs)
+                r = call(main_url, *args, **kwargs)
+            except requests.exceptions.SSLError:
+                raise
             except (
                 requests.exceptions.ConnectionError,
                 requests.exceptions.ReadTimeout,
@@ -442,8 +460,24 @@ def robust(call, maximum_tries=500, retry_after=120):
 
             tries += 1
 
-            LOG.warning("Retrying in %s seconds", retry_after)
-            time.sleep(retry_after)
-            LOG.info("Retrying now...")
+            alternate = None
+            replace = 0
+            if mirrors is not None:
+
+                for key, values in mirrors.items():
+                    if url.startswith(key):
+                        alternate = values
+                        replace = len(key)
+                        if not isinstance(alternate, (list, tuple)):
+                            alternate = [alternate]
+
+            if alternate is not None:
+                mirror = random.choice(alternate)
+                LOG.warning("Retrying using mirror %s", mirror)
+                main_url = f"{mirror}{url[replace:]}"
+            else:
+                LOG.warning("Retrying in %s seconds", retry_after)
+                time.sleep(retry_after)
+                LOG.info("Retrying now...")
 
     return wrapped
